<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <source>MX Welcome</source>
        <translation type="vanished">MX Välkommen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>&amp;Copy for forum</source>
        <translation>&amp;Kopiera för forum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="47"/>
        <source>Save the displayed system information to a text file.</source>
        <translation>Spara den visade systeminformationen till en textfil.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="50"/>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Save text...</source>
        <translation>Spara text...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Copy the displayed system information to the clipboard, encased in [CODE][/CODE] tags ready to use in a forum post.</source>
        <translation>Kopiera den visade systeminformationen till klippbordet, omgiven av [KOD][/KOD]-taggar klara att använda i en forumpost.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="199"/>
        <source>Save the system information selected from the list to an archive file.</source>
        <translation>Spara systeminformationen som valts från en lista till en arkivfil.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="202"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>&amp;Save...</source>
        <translation>S&amp;para...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="164"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>Journald</source>
        <extracomment>systemd journalctl tab</extracomment>
        <translation>Journald</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Log Type</source>
        <extracomment>type of log, either user level or system</extracomment>
        <translation>Loggtyp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>System</source>
        <extracomment>system level log</extracomment>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>User</source>
        <extracomment>user level log</extracomment>
        <translation>Användare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Priority Level</source>
        <extracomment>level of status message to view</extracomment>
        <translation>Prioritetsnivå</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Choose Boot Log</source>
        <extracomment>choose a boot to view the log</extracomment>
        <translation>Välj Boot logg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Service Search</source>
        <extracomment>seek and ye shall find</extracomment>
        <translation>Sök Tjänst</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="199"/>
        <location filename="../mainwindow.cpp" line="344"/>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Quick System Info</source>
        <translation>Snabb Systeminformation</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="61"/>
        <source>Loading...</source>
        <translation>Laddar...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <source>About Quick-System-Info-gui</source>
        <translation>Om Quick-System-Info-gui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>&amp;Find...</source>
        <translation>&amp;Hitta...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Find &amp;Next</source>
        <translation>Hitta N&amp;ästa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>Select &amp;All</source>
        <translation>Välj &amp;Alla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="132"/>
        <source>Revert Selection</source>
        <translation>Ta bort Val</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>Program for displaying a quick system info report</source>
        <translation>Program för att visa en snabb systeminformations-rapport</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="205"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Open folder</source>
        <translation>Öppna katalog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>&amp;Save (×%1)...</source>
        <translation>S&amp;para (×%1)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Find</source>
        <translation>Hitta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="506"/>
        <source>&amp;Find what:</source>
        <translation>&amp;Hitta det :</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>Match c&amp;ase</source>
        <translation>Matcha sk&amp;iftläge</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Match &amp;whole word only</source>
        <translation>Matcha enbart h&amp;ela ord</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>Direction</source>
        <translation>Riktning</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>&amp;Up</source>
        <translation>&amp;Upp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>&amp;Down</source>
        <translation>&amp;Ner</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>Cannot find &quot;%1&quot;</source>
        <translation>Kan inte hitta &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="710"/>
        <source>No journal entries found at this admin and priority level</source>
        <comment>no journal entries found at the options specified</comment>
        <translation>Inga journalposter funna på denna administrations och prioritetsnivå</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <source>Error running journalctl command</source>
        <comment>error report for journalctl command</comment>
        <translation>Fel vid körande av journalctl kommando</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Ändringslogg</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>Save System Information</source>
        <translation>Spara Systeminformation</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>System information saved.</source>
        <translation>Systeminformation sparad.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Could not save system information.</source>
        <translation>Kunde inte spara systeminformation.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>history</source>
        <translation>historia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="82"/>
        <source>Copy for forum</source>
        <translation>Kopiera för forum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>Plain text copy</source>
        <translation>Kopiera ren text</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You must run this program as normal user.</source>
        <translation>Du måste köra det här programmet som vanlig användare.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>This tool displays a the quick system info report in a gui.</source>
        <translation>Detta verktyg visar systeminformation i ett grafiskt användargränssnitt.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
</context>
</TS>